@@ -5,7 +5,7 @@ eval { require DBIx::Class }; return 1 if $@;
 use strict;
 
 __PACKAGE__->table( 'user' );
-__PACKAGE__->add_columns( qw/id username password/ );
+__PACKAGE__->add_columns( qw/id username password session_data/ );
 __PACKAGE__->set_primary_key( 'id' );
 
 __PACKAGE__->has_many(
@@ -16,4 +16,14 @@ __PACKAGE__->has_many(
     return $self->create({ username => $id, password => $password });
 };
 
+eval { require Storable; require MIME::Base64 };
+unless ($@) {
+    __PACKAGE__->inflate_column(
+        session_data => {
+            inflate => sub { Storable::thaw(MIME::Base64::decode_base64(shift)) },
+            deflate => sub { MIME::Base64::encode_base64(Storable::freeze(shift)) },
+        }
+    );
+}
+
 1;
